@@ -1,9 +1,7 @@
 import datetime
 
-from qtpy.QtCharts import QtCharts
-
 from prettyqt import charts
-from prettyqt.utils import to_datetime
+from prettyqt.qt.QtCharts import QtCharts
 
 
 QtCharts.QDateTimeAxis.__bases__ = (charts.AbstractAxis,)
@@ -11,7 +9,7 @@ QtCharts.QDateTimeAxis.__bases__ = (charts.AbstractAxis,)
 
 class DateTimeAxis(QtCharts.QDateTimeAxis):
     def get_min(self) -> datetime.datetime:
-        return to_datetime(self.min())
+        return self.min().toPython()
 
     def get_max(self) -> datetime.datetime:
-        return to_datetime(self.max())
+        return self.max().toPython()
