@@ -1,9 +1,8 @@
 import pathlib
 from typing import Literal, Union
 
-from qtpy import QtCore
-
 from prettyqt import core
+from prettyqt.qt import QtCore
 from prettyqt.utils import InvalidParamError, bidict
 
 
