@@ -1,9 +1,8 @@
 import pathlib
 from typing import Iterator, Literal
 
-from qtpy import QtCore
-
 from prettyqt import core
+from prettyqt.qt import QtCore
 from prettyqt.utils import bidict
 
 
