@@ -1,8 +1,7 @@
 from typing import Optional
 
-from qtpy import QtCore
-
 from prettyqt import core
+from prettyqt.qt import QtCore
 
 
 class TransposeProxyModel(core.AbstractProxyModel):
