@@ -2,7 +2,8 @@ import functools
 import pathlib
 from typing import Any, Callable, Dict, Iterable, Mapping, Optional, Union
 
-from prettyqt import custom_validators, custom_widgets, gui, iconprovider, widgets
+from prettyqt import custom_validators, custom_widgets, gui, widgets
+from prettyqt.utils import types
 
 
 class DataItem:
@@ -411,9 +412,7 @@ class StringOrNumber(DataItem):
 
 
 class Button(DataItem):
-    def __init__(
-        self, label: str, callback: Callable, icon: iconprovider.IconType = None
-    ):
+    def __init__(self, label: str, callback: Callable, icon: types.IconType = None):
         super().__init__("", value=None, include=False)
         self.button_label = label
         self.icon = icon
