@@ -2,9 +2,8 @@ from __future__ import annotations
 
 from typing import List, Optional, Union
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import core, widgets
+from prettyqt.qt import QtCore, QtWidgets
 
 
 class FlowLayout(widgets.Layout):
@@ -114,12 +113,11 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = widgets.Widget()
     layout = FlowLayout()
-    layout += FlowLayout()
-    layout += widgets.PushButton("Short")
-    layout += widgets.PushButton("Longer")
-    layout += widgets.PushButton("Different text")
-    layout += widgets.PushButton("More text")
-    layout += widgets.PushButton("Even longer button text")
+    layout.add(widgets.PushButton("Short"))
+    layout.add(widgets.PushButton("Longer"))
+    layout.add(widgets.PushButton("Different text"))
+    layout.add(widgets.PushButton("More text"))
+    layout.add(widgets.PushButton("Even longer button text"))
     widget.set_layout(layout)
     widget.show()
     app.main_loop()
