@@ -1,8 +1,7 @@
 from typing import List, Optional, Type, Union
 
-from qtpy import QtWidgets
-
 from prettyqt import custom_validators, widgets
+from prettyqt.qt import QtWidgets
 from prettyqt.utils import helpers
 
 
