@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
-from typing import Optional
 import logging
 import re
 import sys
 import traceback
+from typing import Optional
 
 from prettyqt import gui, widgets
 from prettyqt.utils import signallogger
@@ -25,7 +23,7 @@ logger = logging.getLogger(__name__)
 # )
 
 
-class Highlighter(object):
+class Highlighter:
     placeholder: str
     color: Optional[str] = None
     italic: bool = False
@@ -67,9 +65,7 @@ class Message(Highlighter):
             val = traceback.format_exc()
         else:
             val = record.msg % record.args
-        if "\n" in val:
-            val = f"\n{val}"
-        return val
+        return f"\n{val}" if "\n" in val else val
 
 
 class FileName(Highlighter):
@@ -205,7 +201,7 @@ class LogTextEdit(widgets.PlainTextEdit):
         # self.handler = signallogger.LineSignalLogger()
         # self.handler.log_line.connect(self.append_text)
         self.handler = signallogger.RecordSignalLogger()
-        self.handler.log_record.connect(self.append_record)
+        self.handler.signals.log_record.connect(self.append_record)
         widgets.Application.call_on_exit(lambda: logger.removeHandler(self.handler))
         self.handler.setLevel(logging.INFO)
         logger.addHandler(self.handler)
@@ -216,8 +212,7 @@ class LogTextEdit(widgets.PlainTextEdit):
         self.formatter = formatter
         rules = [klass(self.formatter) for klass in Highlighter.__subclasses__()]
         self.rules = [r for r in rules if r.is_included]
-        logger.info("Setting LogTextEdit formatter template to %s", self.formatter._fmt)
-        self.handler.setFormatter(self.formatter)
+        self.handler.setFormatter(formatter)
 
     def append_record(self, record: logging.LogRecord):
         start_of_line = len(self.text())
@@ -271,4 +266,4 @@ if __name__ == "__main__":
     )
     w.box.add(widget)
     w.show()
-    app.exec_()
+    app.main_loop()
