@@ -1,8 +1,7 @@
 from typing import Any, Dict
 
-from qtpy import QtGui
-
 from prettyqt import constants, core
+from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError
 
 
