@@ -1,8 +1,7 @@
-from typing import Literal
-
-from qtpy import QtGui
+from typing import Any, Dict, Literal
 
 from prettyqt import gui
+from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError, bidict, prettyprinter
 
 
@@ -168,7 +167,7 @@ class Font(prettyprinter.PrettyPrinter, QtGui.QFont):
     def __reduce__(self):
         return type(self), (), self.__getstate__()
 
-    def serialize(self):
+    def serialize(self) -> Dict[str, Any]:
         return self.__getstate__()
 
     @property
