@@ -1,6 +1,5 @@
-from qtpy import QtGui
-
 from prettyqt import constants, core
+from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError
 
 
@@ -12,8 +11,15 @@ class FontMetrics(QtGui.QFontMetrics):
             raise InvalidParamError(mode, constants.ELIDE_MODE)
         return self.elidedText(text, constants.ELIDE_MODE[mode], width, flags)
 
-    def get_bounding_rect(self, *args, **kwargs) -> core.Rect:
-        return core.Rect(self.boundingRect(*args, **kwargs))
+    def get_bounding_rect(self, *args) -> core.Rect:
+        return core.Rect(self.boundingRect(*args))
 
     def get_tight_bounding_rect(self, text: str) -> core.Rect:
         return core.Rect(self.tightBoundingRect(text))
+
+
+if __name__ == "__main__":
+    app = QtGui.QGuiApplication([])
+    font = QtGui.QFont()
+    metrics = FontMetrics(font)
+    print(metrics.get_bounding_rect("test"))
