@@ -1,9 +1,8 @@
 import pathlib
 from typing import Iterator, Literal, Union
 
-from qtpy import QtGui
-
 from prettyqt import constants, core, gui
+from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError, bidict
 
 
