@@ -2,9 +2,8 @@ from __future__ import annotations
 
 from typing import Literal
 
-from qtpy import QtLocation
-
 from prettyqt import location
+from prettyqt.qt import QtLocation
 from prettyqt.utils import bidict
 
 
