@@ -1,8 +1,7 @@
 from typing import Literal
 
-from qtpy import QtLocation
-
 from prettyqt import location
+from prettyqt.qt import QtLocation
 from prettyqt.utils import bidict
 
 
