@@ -1,9 +1,8 @@
 import pathlib
 from typing import Iterator, Literal, Optional, Union
 
-from qtpy import QtMultimedia
-
 from prettyqt import core, multimedia
+from prettyqt.qt import QtMultimedia
 from prettyqt.utils import InvalidParamError, bidict
 
 
@@ -35,7 +34,7 @@ class MediaPlaylist(QtMultimedia.QMediaPlaylist):
     def __iter__(self) -> Iterator[multimedia.MediaContent]:
         return iter(self[i] for i in range(self.mediaCount()))
 
-    # def serialize(self):
+    # def serialize(self) -> Dict[str, Any]:
     #     return dict(current_index=self.currentIndex(),
     #                 playback_mode=self.get_playback_mode(),
     #                 items=list(self))
