@@ -1,8 +1,7 @@
 import datetime
 from typing import Union
 
-from qtpy import QtCore, QtNetwork
-
+from prettyqt.qt import QtCore, QtNetwork
 from prettyqt.utils import bidict
 
 
