@@ -1,6 +1,5 @@
-from qtpy import QtCore, QtNetwork
-
 from prettyqt import network
+from prettyqt.qt import QtCore, QtNetwork
 
 
 class NetworkDatagram(QtNetwork.QNetworkDatagram):
