@@ -1,14 +1,7 @@
 from typing import Literal
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtPositioning
-elif PYSIDE2:
-    from PySide2 import QtPositioning
-
 from prettyqt import core
+from prettyqt.qt import QtPositioning
 from prettyqt.utils import bidict
 
 
