@@ -1,16 +1,7 @@
 from typing import Union
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtPositioning
-elif PYSIDE2:
-    from PySide2 import QtPositioning
-
-from qtpy import QtCore
-
 from prettyqt import positioning
+from prettyqt.qt import QtCore, QtPositioning
 from prettyqt.utils import bidict
 
 
