@@ -1,8 +1,7 @@
 from typing import Iterator, Optional, Union
 
-from qtpy import QtCore, QtQml
-
 from prettyqt import core
+from prettyqt.qt import QtCore, QtQml
 
 
 QtQml.QQmlApplicationEngine.__bases__ = (QtQml.QQmlEngine,)
