@@ -8,13 +8,14 @@ if PYQT5:
 elif PYSIDE2:
     from PySide2.QtWidgets import *
 elif PYSIDE6:
-    from PySide6.QtWidgets import *
+    from PySide6.QtWidgets import *  # type: ignore
     from PySide6.QtGui import (  # type: ignore
         QAction,
         QActionGroup,
         QUndoCommand,
         QUndoStack,
         QUndoGroup,
+        QShortcut,
     )
 else:
     raise PythonQtError("No Qt bindings could be found")
