@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # see https://github.com/ITVRoC/SeekurJr/blob/master/seekur_12.04/packages/
 # multimaster_fkie/node_manager_fkie/src/node_manager_fkie/yaml_highlighter.py
 
@@ -11,7 +10,7 @@ from prettyqt import gui
 
 
 @dataclass
-class HighlightRule(object):
+class HighlightRule:
     regex: Union[str, List[str]] = ""
     color: str = "black"
     italic: bool = False
@@ -20,7 +19,7 @@ class HighlightRule(object):
     font_size: Optional[float] = None
     nth: int = 0
     compiled = None
-    fmt = None
+    fmt: gui.TextCharFormat = gui.TextCharFormat()
 
     def __init_subclass__(cls):
         super().__init_subclass__()
@@ -32,7 +31,7 @@ class HighlightRule(object):
         cls.fmt = cls.get_format()
 
     @classmethod
-    def get_format(cls):
+    def get_format(cls) -> gui.TextCharFormat:
         fmt = gui.TextCharFormat()
         fmt.setFontItalic(cls.italic)
         fmt.set_foreground_color(cls.color)
