@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import regex as re
 
 from prettyqt import gui
@@ -40,4 +38,4 @@ if __name__ == "__main__":
     editor = widgets.PlainTextEdit()
     highlighter = JsonHighlighter(editor.document())
     editor.show()
-    app.exec_()
+    app.main_loop()
