@@ -1,14 +1,7 @@
 import logging
 from typing import Literal
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtTextToSpeech  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtTextToSpeech
-
+from prettyqt.qt import QtTextToSpeech
 from prettyqt.utils import bidict
 
 
