@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from typing import Dict, Any, List
 import functools
-import sys
 import operator
+import sys
+from typing import Any, Dict, List
 
 
 def string_to_num_array(array: str) -> List[float]:
@@ -28,7 +26,7 @@ def cut_off_str(obj, max_len: int):
     """
     s = repr(obj)
     if len(s) > max_len - 3:
-        s = s[: max_len - 3] + "..."
+        return s[: max_len - 3] + "..."
     return s
 
 
