@@ -1,12 +1,6 @@
 from typing import List, Union
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWebEngineWidgets  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWebEngineWidgets
+from prettyqt.qt import QtWebEngineWidgets
 
 
 class WebEngineScriptCollection:
