@@ -1,9 +1,9 @@
 import pathlib
 from typing import Callable, Union
-
-from qtpy import QtWebEngineWidgets
+import webbrowser
 
 from prettyqt import core, webenginewidgets, widgets
+from prettyqt.qt import QtCore, QtWebEngineWidgets
 
 
 QtWebEngineWidgets.QWebEngineView.__bases__ = (widgets.Widget,)
@@ -14,7 +14,7 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
         super().__init__(*args, **kwargs)
         self.setPage(webenginewidgets.WebEnginePage(self))
 
-    def set_url(self, url: Union[str, pathlib.Path]):
+    def set_url(self, url: Union[QtCore.QUrl, str, pathlib.Path]):
         """Set the url of the WebEngineView.
 
         Clears the view and loads the URL.
@@ -31,7 +31,7 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
     def get_url(self) -> core.Url:
         return core.Url(self.url())
 
-    def load_url(self, url: Union[str, pathlib.Path]):
+    def load_url(self, url: Union[QtCore.QUrl, str, pathlib.Path]):
         """Load the URL.
 
         Loads the specified url and displays it.
@@ -100,6 +100,36 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
             flag |= QtWebEngineWidgets.QWebEnginePage.FindBackward
         self.findText(string, flag, callback)
 
+    def get_settings(self) -> webenginewidgets.WebEngineSettings:
+        settings = self.settings()
+        return webenginewidgets.WebEngineSettings(settings)
+
+    def set_setting(
+        self,
+        setting_name: webenginewidgets.webenginesettings.WebAttributeStr,
+        value: bool,
+    ):
+        self.get_settings()[setting_name] = value
+
+    def get_setting(
+        self, setting_name: webenginewidgets.webenginesettings.WebAttributeStr
+    ) -> bool:
+        return self.get_settings()[setting_name]
+
+    @classmethod
+    def register_as_browser(cls, tabwidget: widgets.TabWidget):
+        class BuiltInBrowser(webbrowser.BaseBrowser):
+            def open(self, url: str, new: int = 0, autoraise: bool = True):
+                # logger.info(f"opening {url} with builtin browser..")
+                webview = cls()
+                webview.load_url(url)
+                if new == 1:
+                    webview.show()
+                else:
+                    tabwidget.add_tab(webview, str(url), show=autoraise)
+
+        webbrowser.register("BuiltInBrowser", BuiltInBrowser)
+
 
 if __name__ == "__main__":
     from prettyqt import widgets
