@@ -4,7 +4,7 @@ contains QtWidgets-based classes
 """
 
 from prettyqt import core
-from qtpy.QtWidgets import (
+from prettyqt.qt.QtWidgets import (
     QGraphicsSceneHoverEvent as GraphicsSceneHoverEvent,
     QGraphicsSceneMouseEvent as GraphicsSceneMouseEvent,
     QGraphicsSceneWheelEvent as GraphicsSceneWheelEvent,
@@ -95,6 +95,7 @@ from .dialog import BaseDialog, Dialog
 from .messagebox import MessageBox
 from .errormessage import ErrorMessage
 
+from .fileiconprovider import FileIconProvider
 from .filesystemmodel import FileSystemModel
 
 from .slider import Slider
@@ -103,14 +104,14 @@ from .dial import Dial
 from .dockwidget import DockWidget
 
 if core.VersionNumber.get_qt_version() < (6, 0, 0):
-    from .action import Action
-    from .actiongroup import ActionGroup
-    from .shortcut import Shortcut
-    from .undocommand import UndoCommand
-    from .undostack import UndoStack
-    from .undogroup import UndoGroup
     from .keyeventtransition import KeyEventTransition
     from .mouseeventtransition import MouseEventTransition
+from .action import Action
+from .actiongroup import ActionGroup
+from .shortcut import Shortcut
+from .undocommand import UndoCommand
+from .undostack import UndoStack
+from .undogroup import UndoGroup
 from .widgetaction import WidgetAction
 from .menu import Menu
 from .mainwindow import MainWindow
@@ -265,6 +266,7 @@ __all__ = [
     "Dialog",
     "MessageBox",
     "ErrorMessage",
+    "FileIconProvider",
     "FileSystemModel",
     "LayoutItem",
     "Layout",
