@@ -1,6 +1,9 @@
-from qtpy import QtWidgets
+from prettyqt.qt import QtWidgets
 
 
 class ButtonGroup(QtWidgets.QButtonGroup):
+    def serialize_fields(self):
+        return dict(exclusive=self.exclusive())
+
     def __getitem__(self, index: int) -> QtWidgets.QAbstractButton:
         return self.button(index)
