@@ -1,9 +1,8 @@
 from typing import Any, Iterable, Literal, Mapping, Tuple, Union
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import core, gui, iconprovider, widgets
-from prettyqt.utils import InvalidParamError, bidict
+from prettyqt.qt import QtCore, QtWidgets
+from prettyqt.utils import InvalidParamError, bidict, types
 
 
 INSERT_POLICY = bidict(
@@ -29,12 +28,15 @@ InsertPolicyStr = Literal[
 SIZE_ADJUST_POLICY = bidict(
     content=QtWidgets.QComboBox.AdjustToContents,
     first_show=QtWidgets.QComboBox.AdjustToContentsOnFirstShow,
-    min_length=QtWidgets.QComboBox.AdjustToMinimumContentsLength,
+    # min_length=QtWidgets.QComboBox.AdjustToMinimumContentsLength,
     min_length_with_icon=QtWidgets.QComboBox.AdjustToMinimumContentsLengthWithIcon,
 )
 
 SizeAdjustPolicyStr = Literal[
-    "content", "first_show", "min_length", "min_length_with_icon"
+    "content",
+    "first_show",
+    # "min_length",
+    "min_length_with_icon",
 ]
 
 
@@ -111,7 +113,7 @@ class ComboBox(QtWidgets.QComboBox):
         if default is not NoData:
             self.set_value(default)
 
-    def add(self, label: str, data=NoData, icon: iconprovider.IconType = None):
+    def add(self, label: str, data=NoData, icon: types.IconType = None):
         if data is NoData:
             data = label
         if icon is not None:
