@@ -1,8 +1,7 @@
 from typing import Iterator, List
 
-from qtpy import QtWidgets
-
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 QtWidgets.QGraphicsLayout.__bases__ = (widgets.GraphicsLayoutItem,)
