@@ -1,8 +1,8 @@
 from typing import Any, Callable, Iterator, List, Optional, Union
 
-from qtpy import QtWidgets
-
-from prettyqt import core, iconprovider, widgets
+from prettyqt import core, gui, iconprovider, widgets
+from prettyqt.qt import QtWidgets
+from prettyqt.utils import types
 
 
 QtWidgets.QMenu.__bases__ = (widgets.Widget,)
@@ -12,7 +12,7 @@ class Menu(QtWidgets.QMenu):
     def __init__(
         self,
         title: str = "",
-        icon: iconprovider.IconType = None,
+        icon: types.IconType = None,
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(title, parent=parent)
@@ -35,12 +35,21 @@ class Menu(QtWidgets.QMenu):
                 return action
         raise KeyError(f"Action {item} not in menu")
 
+    def serialize_fields(self):
+        return dict(
+            separators_collapsible=self.separatorsCollapsible(),
+            tearoff_enabled=self.isTearOffEnabled(),
+            title=self.title(),
+            tool_tips_visible=self.toolTipsVisible(),
+            icon=self.get_icon(),
+        )
+
     def add(self, *item: QtWidgets.QAction):
         for i in item:
             i.setParent(self)
             self.addAction(i)
 
-    def set_icon(self, icon: iconprovider.IconType):
+    def set_icon(self, icon: types.IconType):
         """Set the icon for the menu.
 
         Args:
@@ -49,6 +58,9 @@ class Menu(QtWidgets.QMenu):
         icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
+    def get_icon(self) -> gui.Icon:
+        return gui.Icon(self.icon())
+
     def add_separator(self, text: Optional[str] = None) -> widgets.WidgetAction:
         """Adds a separator showing an optional label.
 
