@@ -2,10 +2,9 @@ from __future__ import annotations
 
 from typing import Iterator, Literal
 
-from qtpy import QtCore, QtWidgets
-
 from prettyqt import constants, core, gui, iconprovider
-from prettyqt.utils import InvalidParamError, bidict
+from prettyqt.qt import QtCore, QtWidgets
+from prettyqt.utils import InvalidParamError, bidict, types
 
 
 CHILD_INDICATOR_POLICY = bidict(
@@ -65,7 +64,7 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
         order = QtCore.Qt.DescendingOrder if descending else QtCore.Qt.AscendingOrder
         self.sortChildren(column, order)
 
-    def set_icon(self, icon: iconprovider.IconType, column: int = 0):
+    def set_icon(self, icon: types.IconType, column: int = 0):
         """Set the icon for the action.
 
         Args:
