@@ -1,16 +1,9 @@
 import pathlib
 from typing import Literal, Optional, Union
 
-from qtpy import PYQT5, PYSIDE2
-
-
-if PYQT5:
-    from PyQt5 import QtWinExtras  # type: ignore
-elif PYSIDE2:
-    from PySide2 import QtWinExtras
-
 from prettyqt import iconprovider
-from prettyqt.utils import bidict
+from prettyqt.qt import QtWinExtras
+from prettyqt.utils import bidict, types
 
 
 TYPES = bidict(
@@ -47,7 +40,7 @@ class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
         title: str,
         exe_path: Union[str, pathlib.Path],
         arguments: Optional[list] = None,
-        icon: iconprovider.IconType = None,
+        icon: types.IconType = None,
     ) -> None:
         icon = iconprovider.get_icon(icon)
         if arguments is None:
